# Changelog

## [1.2.0](https://github.com/lingjie00/configen/compare/v1.1.1...v1.2.0) (2022-10-23)


### Features

* Added ability to ignore folder name as key [#12](https://github.com/lingjie00/configen/issues/12) from lingjie00/feature/development ([e061329](https://github.com/lingjie00/configen/commit/e0613294dbc3dc387830c10858e9f78206bf469e))

## [1.1.1](https://github.com/lingjie00/configen/compare/v1.1.0...v1.1.1) (2022-09-30)


### Bug Fixes

* change reading order from parser to file order ([8d6084c](https://github.com/lingjie00/configen/commit/8d6084c9d09940632d5b19751089d4de28b5d37a))

## [1.1.0](https://github.com/lingjie00/configen/compare/v1.0.0...v1.1.0) (2022-09-29)


### Features

* allow running configen as module from cli and other fixes ([29a0a18](https://github.com/lingjie00/configen/commit/29a0a18c58eb2ed0974bf3d0d2d1a511d65883c9))


### Bug Fixes

* corrected API doc path ([52e16e1](https://github.com/lingjie00/configen/commit/52e16e1b44b20be020f8f5d8724303ef12651952))

## 1.0.0 (2022-09-23)


### Features

* added API doc ([b47174d](https://github.com/lingjie00/configen/commit/b47174dc80121ca90180e69e59e9dc7de7fdaadd))
* added first version ([9166559](https://github.com/lingjie00/configen/commit/916655968ce2972450ac2307490eacd32879db7f))
* implemented cli ([7815c1f](https://github.com/lingjie00/configen/commit/7815c1f8a26be3370d26938e432286d2f7439064))
* implemented json and yaml parser ([3f414df](https://github.com/lingjie00/configen/commit/3f414dfd07098bda5e6f6f36958d8e4f797922ad))


### Bug Fixes

* corrected auto API doc deployment ([e5f7009](https://github.com/lingjie00/configen/commit/e5f70097e8767e479acec1a3c133b7548fcc76d8))
* corrected workflows ([dc05730](https://github.com/lingjie00/configen/commit/dc05730a1e79c1260b7dc8551e5d78d8d370a2ce))
* disable old test that is not working now and clean up the structure ([c962581](https://github.com/lingjie00/configen/commit/c9625815e62608de8fa1c9313aed370bed9b30aa))
* merge in main ([9b44a0f](https://github.com/lingjie00/configen/commit/9b44a0f3948c3334dd33009f1e1d415f3e0cafdc))
* project bug fixes ([9acea47](https://github.com/lingjie00/configen/commit/9acea47cb82d7ad04853eb7edc48ff3ba4a66908))
* remove dockers from this project ([e55eaae](https://github.com/lingjie00/configen/commit/e55eaae991362718b493cfbb674a599ceaccd3e1))
* remove static docs and change doc format to google ([5505009](https://github.com/lingjie00/configen/commit/5505009262a9711e1742a4e6b1d4373f14ffce29))
